//
//  PreferenceController.m
//  RaiseMan
//
//  Created by narita on 2013/09/19.
//  Copyright (c) 2013年 narita. All rights reserved.
//

#import "PreferenceController.h"

NSString* const BNRTableBgColorKey          = @"BNRTableBgColorKey";
NSString* const BNREmptyDocKey              = @"BNREmptyDocKey";
NSString* const BNRColorChangedNotification = @"BNRColorChangedNotification";


@interface PreferenceController ()

@end

@implementation PreferenceController

+ (void) initialize
{
    NSMutableDictionary* theDefaultValues = [NSMutableDictionary dictionary];
    
    NSData* theColorAsData = [NSKeyedArchiver archivedDataWithRootObject:[NSColor yellowColor]];
    
    [theDefaultValues setObject:theColorAsData forKey:BNRTableBgColorKey];
    [theDefaultValues setObject:[NSNumber numberWithBool:YES] forKey:BNREmptyDocKey];
    
    [[NSUserDefaults standardUserDefaults] registerDefaults:theDefaultValues];
    
    NSLog(@"registered defaults:%@", theDefaultValues);
}

+ (NSColor*) preferenceTableBgColor
{
    NSUserDefaults* theDefault = [NSUserDefaults standardUserDefaults];
    
    NSData* theColorAsData = [theDefault objectForKey:BNRTableBgColorKey];
    
    return [NSKeyedUnarchiver unarchiveObjectWithData:theColorAsData];
}

+ (void)     setPreferenceTableBgColor:(NSColor*)inColor
{
    NSUserDefaults* theDefault = [NSUserDefaults standardUserDefaults];

    NSData* theColorAsData = [NSKeyedArchiver archivedDataWithRootObject:inColor];
    
    [theDefault setObject:theColorAsData
                   forKey:BNRTableBgColorKey];
    
}

+ (BOOL) preferenceEmptyDoc
{
    NSUserDefaults* theDefault = [NSUserDefaults standardUserDefaults];
    
    return [theDefault boolForKey:BNREmptyDocKey];
}

+ (void) setPreferenceEmptyDoc:(BOOL)inEmptyDoc
{
    NSUserDefaults* theDefault = [NSUserDefaults standardUserDefaults];
    
    [theDefault setBool:inEmptyDoc
                 forKey:BNREmptyDocKey];
}


- (id) init
{
    self = [super initWithWindowNibName:@"PreferenceController"];
    
    if (self)
    {

    }
    
    return self;
}

- (void)windowDidLoad
{
    [super windowDidLoad];
    
    [colorWell setColor:[PreferenceController preferenceTableBgColor]];
    
    [checkBox setState:[PreferenceController preferenceEmptyDoc]];
}

- (IBAction) changeBackgroundColor:(id)sender
{
    NSColor* theColor = [colorWell color];
    
    [PreferenceController setPreferenceTableBgColor:theColor];
    
    
    NSNotificationCenter* theNC       = [NSNotificationCenter defaultCenter];
    NSDictionary*         theUserInfo = [NSDictionary dictionaryWithObject:theColor
                                                                    forKey:@"color"];
    
    [theNC postNotificationName:BNRColorChangedNotification
                         object:self
                       userInfo:theUserInfo];
}

- (IBAction) changeNewEmptyDoc:(id)sender
{
    NSInteger theState = [checkBox state];
    
    [PreferenceController setPreferenceEmptyDoc:theState];
}

- (IBAction) resetPreferences:(id)sender
{
    NSUserDefaults* theDefault = [NSUserDefaults standardUserDefaults];
    
    [theDefault removePersistentDomainForName:[[NSBundle mainBundle] bundleIdentifier]];
    
    [colorWell setColor:[PreferenceController preferenceTableBgColor]];
    [checkBox setState:[PreferenceController preferenceEmptyDoc]];
}

@end
